[patch] config/*: Follow spelling conventions.

Kazu Hirata kazu@cs.umass.edu
Sat Sep 6 00:22:00 GMT 2003


Hi,

Attached is a patch to follow spelling conventions.  Committed as
obvious.

Kazu Hirata

2003-09-05  Kazu Hirata  <kazu@cs.umass.edu>

	* config/i860/i860.c: Follow spelling conventions.
	* config/i860/i860.h: Likewise.
	* config/sh/sh.h: Likewise.

Index: config/i860/i860.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/i860/i860.c,v
retrieving revision 1.37
diff -u -r1.37 i860.c
--- config/i860/i860.c	23 Aug 2003 04:20:01 -0000	1.37
+++ config/i860/i860.c	6 Sep 2003 00:20:41 -0000
@@ -61,7 +61,7 @@
 
 rtx i860_compare_op0, i860_compare_op1;
 
-/* Return non-zero if this pattern, can be evaluated safely, even if it
+/* Return nonzero if this pattern, can be evaluated safely, even if it
    was not asked for.  */
 int
 safe_insn_src_p (rtx op, enum machine_mode mode)
@@ -187,7 +187,7 @@
   return 0;
 }
 
-/* Return non-zero if OP can be written to without screwing up
+/* Return nonzero if OP can be written to without screwing up
    GCC's model of what's going on.  It is assumed that this operand
    appears in the dest position of a SET insn in a conditional
    branch's delay slot.  AFTER is the label to start looking from.  */
@@ -256,7 +256,7 @@
 }
 
 
-/* Return non-zero only if OP is a register of mode MODE,
+/* Return nonzero only if OP is a register of mode MODE,
    or const0_rtx.  */
 int
 reg_or_0_operand (rtx op, enum machine_mode mode)
Index: config/sh/sh.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/sh/sh.h,v
retrieving revision 1.220
diff -u -r1.220 sh.h
--- config/sh/sh.h	4 Sep 2003 03:18:00 -0000	1.220
+++ config/sh/sh.h	6 Sep 2003 00:20:44 -0000
@@ -1776,7 +1776,7 @@
   (((COOKIE) >> CALL_COOKIE_INT_REG_SHIFT (REG)) & ((REG) < 4 ? 7 : 15))
     long call_cookie;
 
-  /* This is set to non-zero when the call in question must use the Renesas ABI,
+  /* This is set to nonzero when the call in question must use the Renesas ABI,
      even without the -mrenesas option.  */
     int renesas_abi;
 };



More information about the Gcc-patches mailing list
Index: config/i860/i860.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/i860/i860.h,v
retrieving revision 1.35
diff -u -r1.35 i860.h
--- config/i860/i860.h	23 Aug 2003 05:56:51 -0000	1.35
+++ config/i860/i860.h	6 Sep 2003 00:20:42 -0000
@@ -330,7 +330,7 @@
    : (C) == 'L' ? (unsigned) (VALUE) < 0x10000	\
    : 0)
 
 /* Return non-zero if the given VALUE is acceptable for the
    constraint letter C.  For the i860, constraint letter 'G'
    permits only a floating-point zero value.  */
 #define CONST_DOUBLE_OK_FOR_LETTER_P(VALUE, C)  	\
@@ -344,7 +344,7 @@
 
    If we are trying to put an integer constant into some register, prefer an
    integer register to an FP register.  If we are trying to put a 
-   non-zero floating-point constant into some register, use an integer
+   nonzero floating-point constant into some register, use an integer
    register if the constant is SFmode and GENERAL_REGS is one of our options.
    Otherwise, put the constant into memory.
 
@@ -330,7 +330,7 @@
    : 0)
 
-/* Return non-zero if the given VALUE is acceptable for the
+/* Return nonzero if the given VALUE is acceptable for the
    constraint letter C.  For the i860, constraint letter 'G'
    permits only a floating-point zero value.  */